@@ -21,7 +21,7 @@ Examples:
 mutagene motif --infile sample2.vcf --input-format VCF --genome hg19
 
 # search for the presence of the C[A>T] motif in sample1.maf using hg19 not checking for strand-specificity
-mutagene motif --infile --input-format sample1.maf -f MAF --genome hg19 --motif 'C[A>T]' --strand A
+mutagene motif --infile sample1.maf --input-format MAF --genome hg19 --motif 'C[A>T]' --strand A
         """
 
         ###################################################################
@@ -53,15 +53,19 @@ mutagene motif --infile --input-format sample1.maf -f MAF --genome hg19 --motif
         advanced_group.add_argument(
             '--strand', "-s",
             help="Transcribed strand (T), non-transcribed (N), any (A), or all (TNA default) ",
-            type=str, default='TNA', choices=['T', 'N', 'A', 'TN', 'TA', 'NA', 'TNA'])
+            type=str, default='TNA', choices=['T', 'N', 'A', 'TNA'])
         advanced_group.add_argument(
             '--threshold', "-t",
             help="Significance threshold for qvalues, default value=0.05",
             type=float, default=0.05)
         advanced_group.add_argument(
             '--save-motif-matches',
-            help="Save mutations matching motif(s) to a file",
+            help="Save mutations in matching motifs to a BED file",
             type=argparse.FileType('w'), default=None)
+        advanced_group.add_argument(
+            '--test',
+            help="Statistical test to use",
+            type=str, default='Fisher', choices=['Fisher', 'Chi2'])
 
         self.parser = parser
 
@@ -113,7 +117,8 @@ mutagene motif --infile --input-format sample1.maf -f MAF --genome hg19 --motif
         if len(mutations_with_context) == 0:
             logger.warning("No mutations loaded")
 
-        #### Performance PROFILING
+        #######################
+        # Performance PROFILING
         # import cProfile
         # import pstats
         # pr = cProfile.Profile()
@@ -124,9 +129,11 @@ mutagene motif --infile --input-format sample1.maf -f MAF --genome hg19 --motif
             custom_motif=custom_motif,
             strand=args.strand,
             threshold=args.threshold,
-            dump_matches=args.save_motif_matches) if mutations_with_context is not None else []
+            dump_matches=args.save_motif_matches,
+            stat_type=args.test) if mutations_with_context is not None else []
 
-        #### Performance PROFILING
+        #######################
+        # Performance PROFILING
         # pr.disable()
         # p = pstats.Stats(pr)
         # p.sort_stats('ncalls').print_stats(20)  # strip_dirs()
